@@ -1,8 +1,9 @@
 from lime_etl.domain import exceptions
 from lime_etl.domain.value_objects import *
 from lime_etl.domain.batch_log_entry import *
-from lime_etl.domain.batch_result import *
+from lime_etl.domain.batch_status import *
 from lime_etl.domain.job_result import *
 from lime_etl.domain.job_dependency_errors import *
 from lime_etl.domain.job_log_entry import *
+from lime_etl.domain.job_status import *
 from lime_etl.domain.job_test_result import *
